The [change log][] can be found in the documentation, or you can view the [raw file][] in the repository.

[change log]: https://spacetrack.readthedocs.io/en/latest/changelog.html
[raw file]: docs/changelog.rst
